from setuptools import setup
setup(
    name='dictionarify',
    version='0.0.11',
    author='Surya Narayanan K V',
    author_email='githubsurya@gmail.com',
    description='it is a class which have similar methods to list methods for dictionary',
    long_description='link to documentation- https://github.com/suryavenom/Flexi/blob/main/README.md',
    keywords=['dictionary', 'dictionarify','flexi'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires = '>=3.7'
)


